@@ -2,17 +2,16 @@
 -- Copyright © 2012-2018  Clint Adams
 -- This software is released under the terms of the Expat license.
 -- (See the LICENSE file).
-
-module Data.Conduit.OpenPGP.Compression (
-   conduitCompress
- , conduitDecompress
-) where
+module Data.Conduit.OpenPGP.Compression
+  ( conduitCompress
+  , conduitDecompress
+  ) where
 
 import Codec.Encryption.OpenPGP.Compression
 import Codec.Encryption.OpenPGP.Types
+import Control.Monad.Trans.Resource (MonadThrow)
 import Data.Conduit
 import qualified Data.Conduit.List as CL
-import Control.Monad.Trans.Resource (MonadThrow)
 
 conduitCompress :: MonadThrow m => CompressionAlgorithm -> ConduitT Pkt Pkt m ()
 conduitCompress algo = CL.consume >>= \ps -> yield (compressPkts algo ps)
